

#ifdef GL_ES
    precision   lowp            float;
    varying     lowp vec4       v_fragmentColor;
    varying     lowp vec4       v_fragmentColorOffset;
#else
    varying     lowp            v_fragmentColor;
    varying     lowp            v_fragmentColorOffset;
#endif

varying vec2        v_texCoord;
varying lowp vec3   v_colorMul;
varying lowp vec3   v_colorAdd;

uniform sampler2D   u_texture;
uniform sampler2D   u_sub_texture;
uniform	float       u_alpha_value;

void main()
{
	vec4 texColor       = texture2D(u_texture    , v_texCoord);
    vec4 sub_texColor   = texture2D(u_sub_texture, v_texCoord);
	
    // alpha test
	if ( texColor.a <= u_alpha_value )
	{
		discard;
	}
	
    vec3  tex_scaled    = vec3(texColor.rgb);
    
    float interpolate   = sub_texColor.a;
    interpolate         = interpolate * min( 3.0, 1.0/interpolate );
    
    vec3 paletted       = (tex_scaled*v_colorMul + v_colorAdd);
        
	vec3 texRGB         = (1.0 - interpolate)*tex_scaled + (interpolate)*( paletted );
	
	vec3 fragRGB        = vec3(v_fragmentColor.rgb);

	// calculate alpha
	vec4 alpha_cal      = texColor*v_fragmentColor + v_fragmentColorOffset;
	
	// multiply RGB
	// Note: the RGB vectors do not contain alpha, so the RGB values are not multiplied by alpha at this stage
	
    vec3 multiplyRGB    = texRGB * fragRGB ;
	
	// Add RGB offsets, then multiply by alpha
	
    vec3 rgb           = (multiplyRGB + v_fragmentColorOffset.rgb) * alpha_cal.aaa;
	
	// combine RGB + A for final color
	gl_FragColor = vec4(rgb, alpha_cal.a);
 
}
