// http://www.cocos2d-iphone.org


#ifdef GL_ES
precision   lowp            float;
varying     lowp vec4       v_fragmentColor;
varying     lowp vec4       v_fragmentColorOffset;
#else
varying     lowp            v_fragmentColor;
varying     lowp            v_fragmentColorOffset;
#endif

varying float       v_tex_sel;
varying vec2        v_texCoord;
uniform sampler2D   u_texture;
//uniform sampler2D   u_texturesub;
uniform	float       u_alpha_value;


void main()
{
	vec4 texColor   = texture2D(u_texture   , v_texCoord);
//	vec4 texColor1  = texture2D(u_texturesub, v_texCoord);
    
	// alpha test
	if ( texColor.a <= u_alpha_value )
	{
		discard;
	}
    
	// extract RGB components, and 'un-premuliply' alpha value
	// We multiple the final colors by alpha later, so we need to divide it out here
	// in order to avoid artifacts that could be induced by the 'modulate then add' strategy
    
	vec3 texRGB         = vec3(texColor.rgb) / texColor.a;
	
	vec3 fragRGB        = vec3(v_fragmentColor.rgb);
    
	// calculate alpha
	vec4 alpha_cal      = texColor*v_fragmentColor + v_fragmentColorOffset;
	
	// multiply RGB
	// Note: the RGB vectors do not contain alpha, so the RGB values are not multiplied by alpha at this stage
	
    vec3 multiplyRGB    = texRGB * fragRGB * v_tex_sel;
	
	// Add RGB offsets, then multiply by alpha
	
    
    vec3 rgb           = (multiplyRGB + v_fragmentColorOffset.rgb) * alpha_cal.aaa;
	
	// combine RGB + A for final color
	gl_FragColor = vec4(rgb, alpha_cal.a);
}